@@ -1,19 +1,10 @@
 import asyncio
 import logging
 from datetime import datetime, timedelta
-from typing import Iterable, NoReturn, Tuple, TypeVar
+from typing import Iterable, NoReturn, Tuple, TypeVar, cast
 
 from expression.collections import seq
-from expression.core import (
-    MailboxProcessor,
-    TailCall,
-    aiotools,
-    match,
-    pipe,
-    tailrec_async,
-    snd,
-    TailCallResult,
-)
+from expression.core import MailboxProcessor, TailCall, TailCallResult, aiotools, fst, match, pipe, tailrec_async
 from expression.system import CancellationTokenSource
 
 from .combine import with_latest_from
@@ -22,13 +13,14 @@ from .notification import Notification, OnCompleted, OnError, OnNext
 from .observables import AsyncAnonymousObservable
 from .observers import AsyncNotificationObserver, auto_detach_observer
 from .transform import map
-from .types import AsyncDisposable, AsyncObservable, AsyncObserver, Stream
+from .types import AsyncDisposable, AsyncObservable, AsyncObserver, Projection
 
 TSource = TypeVar("TSource")
+TSource_ = TypeVar("TSource_")
 log = logging.getLogger(__name__)
 
 
-def delay(seconds: float) -> Stream[TSource, TSource]:
+def delay(seconds: float) -> Projection[TSource, TSource]:
     """Delay observable.
 
     Time shifts the observable sequence by the given timeout. The
@@ -43,11 +35,15 @@ def delay(seconds: float) -> Stream[TSource, TSource]:
 
     def _delay(source: AsyncObservable[TSource]) -> AsyncObservable[TSource]:
         cts = CancellationTokenSource()
+        token = cts.token
 
         async def subscribe_async(aobv: AsyncObserver[TSource]) -> AsyncDisposable:
             async def worker(inbox: MailboxProcessor[Tuple[Notification[TSource], datetime]]) -> None:
                 @tailrec_async
-                async def loop() -> TailCallResult[NoReturn]:
+                async def loop() -> TailCallResult[None]:
+                    if token.is_cancellation_requested:
+                        return
+
                     ns, due_time = await inbox.receive()
 
                     diff = due_time - datetime.utcnow()
@@ -56,32 +52,33 @@ def delay(seconds: float) -> Stream[TSource, TSource]:
                         await asyncio.sleep(seconds)
 
                     async def matcher() -> None:
-                        with match(ns) as m:
-                            for x in OnNext.case(m):
+                        with match(ns) as case:
+                            for x in case(OnNext[TSource]):
                                 await aobv.asend(x)
                                 return
-                            for err in OnError.case(m):
+                            for err in case(OnError[TSource]):
                                 await aobv.athrow(err)
                                 return
-                            while m.case(OnCompleted):
+                            for x in case(OnCompleted):
                                 await aobv.aclose()
                                 return
 
                     await matcher()
                     return TailCall()
 
-                await loop()
+                asyncio.ensure_future(loop())
 
-            agent = MailboxProcessor.start(worker, cts.token)
+            agent = MailboxProcessor.start(worker, token)
 
             async def fn(ns: Notification[TSource]) -> None:
                 due_time = datetime.utcnow() + timedelta(seconds=seconds)
                 agent.post((ns, due_time))
 
             obv: AsyncNotificationObserver[TSource] = AsyncNotificationObserver(fn)
-            subscription = await pipe(obv, source.subscribe_async)
+            subscription = await source.subscribe_async(obv)
 
             async def cancel() -> None:
+                log.debug("delay:cancel()")
                 cts.cancel()
                 await subscription.dispose_async()
 
@@ -92,30 +89,30 @@ def delay(seconds: float) -> Stream[TSource, TSource]:
     return _delay
 
 
-def debounce(seconds: float) -> Stream[TSource, TSource]:
+def debounce(seconds: float) -> Projection[TSource, TSource]:
     def _debounce(source: AsyncObservable[TSource]) -> AsyncObservable[TSource]:
         async def subscribe_async(aobv: AsyncObserver[TSource]) -> AsyncDisposable:
             safe_obv, auto_detach = auto_detach_observer(aobv)
-            infinite: Iterable[int] = seq.infinite()
+            infinite: Iterable[int] = seq.infinite
 
             async def worker(inbox: MailboxProcessor[Tuple[Notification[TSource], int]]) -> None:
                 @tailrec_async
                 async def message_loop(current_index: int) -> TailCallResult[NoReturn]:
                     n, index = await inbox.receive()
 
-                    with match(n) as m:
+                    with match(n) as case:
                         log.debug("debounce: %s, %d, %d", n, index, current_index)
-                        for x in OnNext.case(m):
+                        for x in case(OnNext[TSource]):
                             if index == current_index:
                                 await safe_obv.asend(x)
                                 current_index = index
                             elif index > current_index:
                                 current_index = index
 
-                        for err in OnError.case(m):
+                        for err in case(OnError[TSource]):
                             await safe_obv.athrow(err)
 
-                        while m.case(OnCompleted):
+                        while case(OnCompleted):
                             await safe_obv.aclose()
 
                     return TailCall(current_index)
@@ -151,13 +148,20 @@ def debounce(seconds: float) -> Stream[TSource, TSource]:
     return _debounce
 
 
-def sample(seconds: float) -> Stream[TSource, TSource]:
+def sample(seconds: float) -> Projection[TSource_, TSource_]:
     def _sample(source: AsyncObservable[TSource]) -> AsyncObservable[TSource]:
         timer = interval(seconds, seconds)
 
+        mapper = cast(Projection[Tuple[TSource, int], TSource], map(fst))  # FIXME: pyright issue
+
         if seconds > 0:
-            return pipe(source, with_latest_from(timer), map(snd))
-        else:
-            return source
+            ret = pipe(
+                source,
+                with_latest_from(timer),
+                mapper,
+            )
+            return ret
+
+        return source
 
     return _sample
